==> minnwest_esb_client_q2-2.0.0-py3-none-any.whl: minnwest_esb_client_q2/api/enrollment/post_api_v_1_q_2_enrollment_view_enrollment.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.portfolio_transfer_view_request import PortfolioTransferViewRequest
from ...models.problem_details import ProblemDetails
from ...models.soa_enrollment_account_api_result import SOAEnrollmentAccountApiResult
from ...models.validation_problem_details import ValidationProblemDetails
from ...types import Response


def _get_kwargs(
    *,
    body: PortfolioTransferViewRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api/v1-q2/Enrollment/view/enrollment",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    if response.status_code == 200:
        response_200 = SOAEnrollmentAccountApiResult.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = ValidationProblemDetails.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = ProblemDetails.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = ProblemDetails.from_dict(response.json())

        return response_403
    if response.status_code == 500:
        response_500 = ProblemDetails.from_dict(response.json())

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PortfolioTransferViewRequest,
) -> Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (PortfolioTransferViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PortfolioTransferViewRequest,
) -> Optional[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (PortfolioTransferViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PortfolioTransferViewRequest,
) -> Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (PortfolioTransferViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: PortfolioTransferViewRequest,
) -> Optional[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (PortfolioTransferViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed

==> minnwest_esb_client_q2-2.1.0-py3-none-any.whl: minnwest_esb_client_q2/api/enrollment/post_api_v_1_q_2_enrollment_view_enrollment.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.enrollment_view_request import EnrollmentViewRequest
from ...models.problem_details import ProblemDetails
from ...models.soa_enrollment_account_api_result import SOAEnrollmentAccountApiResult
from ...models.validation_problem_details import ValidationProblemDetails
from ...types import Response


def _get_kwargs(
    *,
    body: EnrollmentViewRequest,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/api/v1-q2/Enrollment/view/enrollment",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    if response.status_code == 200:
        response_200 = SOAEnrollmentAccountApiResult.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = ValidationProblemDetails.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = ProblemDetails.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = ProblemDetails.from_dict(response.json())

        return response_403
    if response.status_code == 500:
        response_500 = ProblemDetails.from_dict(response.json())

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: EnrollmentViewRequest,
) -> Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (EnrollmentViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: EnrollmentViewRequest,
) -> Optional[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (EnrollmentViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]
    """

    return sync_detailed(
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: EnrollmentViewRequest,
) -> Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (EnrollmentViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: EnrollmentViewRequest,
) -> Optional[Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]]:
    """Get Account and Customer information.

    Args:
        body (EnrollmentViewRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ProblemDetails, SOAEnrollmentAccountApiResult, ValidationProblemDetails]
    """

    return (
        await asyncio_detailed(
            client=client,
            body=body,
        )
    ).parsed
